({
    "title": "OPC-UA 驱动",
    "key": "opcua",
    "model": {
        "properties": {
            "settings": {
                "title": "设备配置",
                "type": "object",
                "properties": {
                    "endPointUrl": {
                        "type": "string",
                        "title": "OPC主机URL"
                    },
                    "securityMode": {
                        "type": "string",
                        "enum": ["None", "Sign", "Sign&Encrypt"],
                        "title": "安全模式"
                    },
                    "securityPolicy": {
                        "type": "string",
                        "enum": ["None", "Basic128Rsa15", "Basic256", "Basic256Sha256"],
                        "title": "安全策略"
                    },
                    "providerUserName": {
                        "type": "string",
                        "title": "用户名"
                    },
                    "providerPassword": {
                        "type": "string",
                        "title": "密码",
                        "description": "如果没有用户名密码便进行匿名访问",
                        "fieldType": "password"
                    },
                    "itemPrefix": {
                        "type": "string",
                        "title": "数据点前缀",
                        "description": "影响数据点配置中的数据点ID"
                    },
                    "interval": {
                        "type": "number",
                        "title": "采集周期 (s)",
                        "description": "数据点的采集周期，不定义默认5秒"
                    },
                    "network": {
                        "type": "object",
                        "title": "通讯监控参数",
                        "properties": {
                            "timeout": {
                                "title": "通讯超时时间(s)",
                                "description": "经过多长时间仪表还没有任何数据上传，认定为通讯故障，默认为周期的3倍",
                                "type": "number"
                            }
                        },
                        "form": [{
                            "key": "timeout",
                        }]
                    }
                },
                "required": ["endPointUrl", "securityMode", "securityPolicy"]
            },
            "tags": {
                "title": "数据点",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "id": {
                            "type": "string",
                            "title": "标识"
                        },
                        "namespaceIndex": {
                            "type": "number",
                            "title": "命名空间",
                            "description": "namespaceIndex,填写数字"
                        },
                        "identifier": {
                            "type": "string",
                            "title": "数据点ID",
                            "description": "identifier,实际值为数据点前缀与此栏拼接而成"
                        },
                        "idType": {
                            "type": "string",
                            "enum": ["s", "i", "u", "b"],
                            "enum_title": ["字符串String", "数字Numeric", "GUID", "未知Opaque"],
                            "title": "数据点ID类型",
                            "description": "identifierType,缺省为字符串"
                        },
                        "rw": {
                            "type": "boolean",
                            "title": "允许指令写入",
                            "description": "缺省为false"
                        },
                        "dataType": {
                            "type": "string",
                            "title": "数据类型",
                            "description": "允许写入数据点时需要配置数据类型，缺省为Float",
                            "enum": [
                                "FLOAT",
                                "DOUBLE",
                                "BOOL",
                                "SIGNED_SHORT",
                                "SIGNED_INTEGER",
                                "SIGNED_LONG",
                                "UNSIGNED_SHORT",
                                "UNSIGNED_INTEGER",
                                "UNSIGNED_LONG",
                                "STRING",
                                "SIGNED_BYTE",
                                "UNSIGNED_BYTE"
                            ],
                            "enum_title": [
                                "Float",
                                "Double",
                                "Bool",
                                "Int16(SIGNED_SHORT)",
                                "Int32(SIGNED_INTEGER)",
                                "Int64(SIGNED_LONG)",
                                "UInt16(UNSIGNED_SHORT)",
                                "UInt32(UNSIGNED_INTEGER)",
                                "UInt64(UNSIGNED_LONG)",
                                "String",
                                "SByte(SIGNED_BYTE)",
                                "UByte(UNSIGNED_BYTE)"
                            ]
                        }
                    },
                    "required": ["name", "id", "namespaceIndex", "identifier"]
                }
            },
            "commands": {
                "title": "命令",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "ops": {
                            "type": "array",
                            "title": "指令",
                            "items": {
                                "type": "object",
                                "properties": {
                                    "namespaceIndex": {
                                        "type": "string",
                                        "title": "命名空间",
                                        "description": "namespaceIndex,填写数字"
                                    },
                                    "identifier": {
                                        "type": "string",
                                        "title": "数据点ID",
                                        "description": "identifier(全名，不受前缀影响)"
                                    },
                                    "dataType": {
                                        "type": "string",
                                        "title": "数据类型",
                                        "description": "写入点的数据类型，不匹配时可能导致写入失败",
                                        "enum": [
                                            "FLOAT",
                                            "DOUBLE",
                                            "BOOL",
                                            "SIGNED_SHORT",
                                            "SIGNED_INTEGER",
                                            "SIGNED_LONG",
                                            "UNSIGNED_SHORT",
                                            "UNSIGNED_INTEGER",
                                            "UNSIGNED_LONG",
                                            "STRING",
                                            "SIGNED_BYTE",
                                            "UNSIGNED_BYTE"
                                        ],
                                        "enum_title": [
                                            "Float",
                                            "Double",
                                            "Bool",
                                            "Int16(SIGNED_SHORT)",
                                            "Int32(SIGNED_INTEGER)",
                                            "Int64(SIGNED_LONG)",
                                            "UInt16(UNSIGNED_SHORT)",
                                            "UInt32(UNSIGNED_INTEGER)",
                                            "UInt64(UNSIGNED_LONG)",
                                            "String",
                                            "SByte(SIGNED_BYTE)",
                                            "UBytE(UNSIGNED_BYTE)"
                                        ]
                                    },
                                    "idType": {
                                        "type": "string",
                                        "enum": [
                                            "s",
                                            "i",
                                            "u",
                                            "b"
                                        ],
                                        "enum_title": [
                                            "字符串String",
                                            "数字Numeric",
                                            "GUID",
                                            "未知Opaque"
                                        ],
                                        "title": "数据点ID类型",
                                        "description": "identifierType,缺省为字符串"
                                    },
                                    "param": {
                                        "type": "string",
                                        "title": "绑定表单项",
                                        "description": "填写表单项的名称"
                                    },
                                    "value": {
                                        "type": "string",
                                        "title": "默认写入值"
                                    }
                                },
                                "required": [
                                    "namespaceIndex",
                                    "identifier",
                                    "dataType"
                                ]
                            }
                        }
                    }
                }
            }
        }
    },
    "device": {
        "properties": {
            "settings": {
                "title": "设备配置",
                "type": "object",
                "properties": {
                    "endPointUrl": {
                        "type": "string",
                        "title": "OPC主机URL"
                    },
                    "securityMode": {
                        "type": "string",
                        "enum": ["None", "Sign", "Sign&Encrypt"],
                        "title": "安全模式"
                    },
                    "securityPolicy": {
                        "type": "string",
                        "enum": ["None", "Basic128Rsa15", "Basic256", "Basic256Sha256"],
                        "title": "安全策略"
                    },
                    "providerUserName": {
                        "type": "string",
                        "title": "用户名"
                    },
                    "providerPassword": {
                        "type": "string",
                        "title": "密码",
                        "description": "如果没有用户名密码便进行匿名访问",
                        "fieldType": "password"
                    },
                    "itemPrefix": {
                        "type": "string",
                        "title": "数据点前缀",
                        "description": "影响数据点配置中的数据点ID"
                    },
                    "interval": {
                        "type": "number",
                        "title": "采集周期 (s)",
                        "description": "数据点的采集周期，不定义默认5秒"
                    },
                    "overWrite": {
                        "type": "boolean",
                        "title": "不继承模型的数据点",
                        "description": "默认情况下资产数据点为其自身的和模型的数据点的合集"
                    },
                    "network": {
                        "type": "object",
                        "title": "通讯监控参数",
                        "properties": {
                            "timeout": {
                                "title": "通讯超时时间(s)",
                                "description": "经过多长时间仪表还没有任何数据上传，认定为通讯故障，默认为周期的3倍",
                                "type": "number"
                            }
                        },
                        "form": [{
                            "key": "timeout",
                        }]
                    }
                },
                "required": ["endPointUrl", "securityMode", "securityPolicy"]
            },
            "tags": {
                "title": "数据点",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "id": {
                            "type": "string",
                            "title": "标识"
                        },
                        "namespaceIndex": {
                            "type": "string",
                            "title": "命名空间",
                            "description": "namespaceIndex,填写数字"
                        },
                        "identifier": {
                            "type": "string",
                            "title": "数据点ID",
                            "description": "identifier,实际值为数据点前缀与此栏拼接而成"
                        },
                        "idType": {
                            "type": "string",
                            "enum": ["s", "i", "u", "b"],
                            "enum_title": ["字符串String", "数字Numeric", "GUID", "未知Opaque"],
                            "title": "数据点ID类型",
                            "description": "identifierType,缺省为字符串"
                        },
                        "rw": {
                            "type": "boolean",
                            "title": "允许指令写入",
                            "description": "缺省为false"
                        },
                        "dataType": {
                            "type": "string",
                            "title": "数据类型",
                            "description": "允许写入数据点时需要配置数据类型，缺省为Float",
                            "enum": [
                                "FLOAT",
                                "DOUBLE",
                                "BOOL",
                                "SIGNED_SHORT",
                                "SIGNED_INTEGER",
                                "SIGNED_LONG",
                                "UNSIGNED_SHORT",
                                "UNSIGNED_INTEGER",
                                "UNSIGNED_LONG",
                                "STRING",
                                "SIGNED_BYTE",
                                "UNSIGNED_BYTE"
                            ],
                            "enum_title": [
                                "Float",
                                "Double",
                                "Bool",
                                "Int16(SIGNED_SHORT)",
                                "Int32(SIGNED_INTEGER)",
                                "Int64(SIGNED_LONG)",
                                "UInt16(UNSIGNED_SHORT)",
                                "UInt32(UNSIGNED_INTEGER)",
                                "UInt64(UNSIGNED_LONG)",
                                "String",
                                "SByte(SIGNED_BYTE)",
                                "UBytE(UNSIGNED_BYTE)"
                            ]
                        }
                    },
                    "required": ["name", "id", "namespaceIndex", "identifier"]
                }
            },
            "commands": {
                "title": "命令",
                "type": "array",
                "items": {
                    "type": "object",
                    "properties": {
                        "name": {
                            "type": "string",
                            "title": "名称"
                        },
                        "ops": {
                            "type": "array",
                            "title": "指令",
                            "items": {
                                "type": "object",
                                "properties": {
                                    "namespaceIndex": {
                                        "type": "string",
                                        "title": "命名空间",
                                        "description": "namespaceIndex,填写数字"
                                    },
                                    "identifier": {
                                        "type": "string",
                                        "title": "数据点ID",
                                        "description": "identifier(全名，不受前缀影响)"
                                    },
                                    "dataType": {
                                        "type": "string",
                                        "title": "数据类型",
                                        "description": "写入点的数据类型，不匹配时可能导致写入失败",
                                        "enum": [
                                            "FLOAT",
                                            "DOUBLE",
                                            "BOOL",
                                            "SIGNED_SHORT",
                                            "SIGNED_INTEGER",
                                            "SIGNED_LONG",
                                            "UNSIGNED_SHORT",
                                            "UNSIGNED_INTEGER",
                                            "UNSIGNED_LONG",
                                            "STRING",
                                            "SIGNED_BYTE",
                                            "UNSIGNED_BYTE"
                                        ],
                                        "enum_title": [
                                            "Float",
                                            "Double",
                                            "Bool",
                                            "Int16(SIGNED_SHORT)",
                                            "Int32(SIGNED_INTEGER)",
                                            "Int64(SIGNED_LONG)",
                                            "UInt16(UNSIGNED_SHORT)",
                                            "UInt32(UNSIGNED_INTEGER)",
                                            "UInt64(UNSIGNED_LONG)",
                                            "String",
                                            "SByte(SIGNED_BYTE)",
                                            "UBytE(UNSIGNED_BYTE)"
                                        ]
                                    },
                                    "idType": {
                                        "type": "string",
                                        "enum": [
                                            "s",
                                            "i",
                                            "u",
                                            "b"
                                        ],
                                        "enum_title": [
                                            "字符串String",
                                            "数字Numeric",
                                            "GUID",
                                            "未知Opaque"
                                        ],
                                        "title": "数据点ID类型",
                                        "description": "identifierType,缺省为字符串"
                                    },
                                    "param": {
                                        "type": "string",
                                        "title": "绑定表单项",
                                        "description": "填写表单项的名称"
                                    },
                                    "value": {
                                        "type": "string",
                                        "title": "默认写入值"
                                    }
                                },
                                "required": [
                                    "namespaceIndex",
                                    "identifier",
                                    "dataType"
                                ]
                            }
                        }
                    }
                }
            }
        }
    }
})
